@@ -1,10 +1,10 @@
 package WWW::Vimeo::Simple::Activity;
 {
-  $WWW::Vimeo::Simple::Activity::VERSION = '0.07';
+  $WWW::Vimeo::Simple::Activity::VERSION = '0.08';
 }
 
 use JSON;
-use Moose;
+use Mouse;
 use HTTP::Tiny;
 
 use WWW::Vimeo::Simple;
@@ -19,7 +19,7 @@ WWW::Vimeo::Simple::Activity - Activity requests for the Vimeo Simple API
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -201,7 +201,7 @@ Alessandro Ghedini <alexbio@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Alessandro Ghedini.
+Copyright 2011 Alessandro Ghedini.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
