@@ -1,10 +1,10 @@
 package WWW::Vimeo::Simple::Group;
 {
-  $WWW::Vimeo::Simple::Group::VERSION = '0.07';
+  $WWW::Vimeo::Simple::Group::VERSION = '0.08';
 }
 
 use JSON;
-use Moose;
+use Mouse;
 use HTTP::Tiny;
 
 use WWW::Vimeo::Simple;
@@ -20,7 +20,7 @@ WWW::Vimeo::Simple::Group - Group requests for the Vimeo Simple API
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -331,7 +331,7 @@ Alessandro Ghedini <alexbio@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Alessandro Ghedini.
+Copyright 2011 Alessandro Ghedini.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
